@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 import os
 
-from dci_downloader.api import get_files_list, get_repo_base_url, download_file
+from dci_downloader.api import get_files_list, get_base_url, download_files
 from dci_downloader.stats import check_download_folder_size
 from dci_downloader.filters import filter_files_list
 from dci_downloader.files_list import get_files_to_download, get_files_to_remove
@@ -10,8 +10,7 @@ from dci_downloader.fs import (
     mkdir_p,
     delete_all_symlink_in_path,
     recreate_symlinks,
-    build_download_folder,
-    create_parent_dir,
+    get_component_folder,
 )
 
 
@@ -26,20 +25,15 @@ def clean_download_folder(files_list, download_folder):
     delete_all_symlink_in_path(download_folder)
 
 
-def download_component(topic, component, settings, cert, key):
+def download_component(topic, component, settings):
     print("Download component %s" % component["name"])
-    base_url = get_repo_base_url(topic, component)
-    files_list = get_files_list(base_url, cert, key)
-    download_folder = build_download_folder(
-        topic, component, settings["download_folder"]
-    )
+    base_url = get_base_url(topic, component)
+    files_list = get_files_list(base_url, settings)
+    if component["type"].lower() == "compose":
+        files_list = filter_files_list(files_list, settings)
+    download_folder = get_component_folder(settings, component)
     clean_download_folder(files_list, download_folder)
-    files_list = filter_files_list(files_list, settings)
     files_to_download = get_files_to_download(base_url, download_folder, files_list)
     check_download_folder_size(files_to_download, download_folder)
-    nb_files = len(files_to_download['files'])
-    for index, file in enumerate(files_to_download['files']):
-        print("(%d/%d): %s" % (index, nb_files, file["destination"]))
-        create_parent_dir(file["destination"])
-        download_file(file, cert, key)
+    download_files(files_to_download["files"], settings)
     recreate_symlinks(files_list["symlinks"], download_folder)
