@@ -37,19 +37,22 @@ def _clean_topic(topic):
     archs = topic["archs"] if "archs" in topic else ["x86_64"]
     variants = topic["variants"] if "variants" in topic else []
     variants = [
-        v if type(v) is dict else {"name": v, "with_debug": False, "with_iso": False} for v in variants
+        v if type(v) is dict else {"name": v, "with_debug": False, "with_iso": False}
+        for v in variants
     ]
-    all = topic["download_everything"] if "download_everything" in topic else False
     return {
         "name": name,
         "components": components,
         "archs": archs,
         "variants": variants,
-        "download_everything": all,
+        "download_everything": topic["download_everything"]
+        if "download_everything" in topic
+        else False,
         "download_folder": topic["download_folder"],
         "dci_key_file": topic["dci_key_file"],
         "dci_cert_file": topic["dci_cert_file"],
         "component_id": component_id,
+        "with_debug": topic["with_debug"] if "with_debug" in topic else False,
     }
 
 
@@ -115,12 +118,18 @@ def get_settings(sys_args, env_variables={}):
 def _variants_are_invalid(topic):
     topic_variants = {
         "RHEL-7": [
+            "Client-optional",
+            "Client",
+            "ComputeNode-optional",
+            "ComputeNode",
             "Server-NFV",
             "Server-RT",
             "Server-SAP",
             "Server-SAPHANA",
             "Server-optional",
             "Server",
+            "Workstation-optional",
+            "Workstation",
         ],
         "RHEL-8": [
             "AppStream",
@@ -132,7 +141,17 @@ def _variants_are_invalid(topic):
             "ResilientStorage",
             "SAP",
             "SAPHANA",
-            "unified",
+        ],
+        "RHEL-9": [
+            "AppStream",
+            "BaseOS",
+            "CRB",
+            "HighAvailability",
+            "NFV",
+            "RT",
+            "ResilientStorage",
+            "SAP",
+            "SAPHANA",
         ],
     }
     invalid = False
@@ -154,6 +173,30 @@ def _variants_are_invalid(topic):
     return invalid
 
 
+def _arches_are_invalid(topic):
+    topic_archs = {
+        "RHEL-7": ["ppc64", "ppc64le", "s390x", "x86_64"],
+        "RHEL-8": ["aarch64", "ppc64le", "s390x", "x86_64"],
+        "RHEL-9": ["aarch64", "ppc64le", "s390x", "x86_64"],
+    }
+    invalid = False
+    current_topic_name = topic["name"]
+    for topic_name, archs in topic_archs.items():
+        archs_not_allowed = set(topic["archs"]) - set(archs)
+        if current_topic_name.startswith(topic_name) and archs_not_allowed:
+            invalid = True
+            print(
+                "Arches %s for the %s topic are not valid"
+                % (", ".join(archs_not_allowed), current_topic_name)
+            )
+            print(
+                "The authorized archs for %s are %s."
+                % (current_topic_name, ", ".join(archs))
+            )
+            break
+    return invalid
+
+
 def exit_if_settings_invalid(settings):
     has_error = False
     for env_variable in ["DCI_CLIENT_ID", "DCI_API_SECRET", "DCI_CS_URL"]:
@@ -173,6 +216,8 @@ def exit_if_settings_invalid(settings):
     for topic in topics:
         if _variants_are_invalid(topic):
             has_error = True
+        if _arches_are_invalid(topic):
+            has_error = True
 
     if has_error:
         sys.exit(1)
